@@ -8,12 +8,12 @@ except ImportError:
     FLICKR_SETTINGS = None
 
 
-@skipIf(FLICKR_SETTINGS is None, 'You must provide "FLICKR_SETTINGS" in your "settings_local.py". See: "settings_local_example.py".')
-class FlickrTests(TestCase):
+class FlickrLiveTests(TestCase):
     
     def setUp(self):
         self.client = api.FlickrClient(FLICKR_SETTINGS['API_KEY'])
     
+    @skipIf(FLICKR_SETTINGS is None, 'You must provide "FLICKR_SETTINGS" in your "settings_local.py". See: "settings_local_example.py".')
     def test_get_recent(self):
         recent_photos = api.FlickrPhoto.objects.get_recent(client=self.client)
         self.assertTrue(len(recent_photos) > 0, 'No search results for recent photo\'s? This cannot be correct!')
@@ -24,6 +24,7 @@ class FlickrTests(TestCase):
         self.assertFalse('description' in photo.data)
         self.assertTrue(photo.get_url().endswith('.jpg'))
 
+    @skipIf(FLICKR_SETTINGS is None, 'You must provide "FLICKR_SETTINGS" in your "settings_local.py". See: "settings_local_example.py".')
     def test_get(self):
         recent_photos = api.FlickrPhoto.objects.get_recent(client=self.client)
         self.assertTrue(len(recent_photos) > 0, 'No search results for recent photo\'s? This cannot be correct!')
